==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/System.Web/System.Web.UI/HtmlTextWriterStyle.cs <==
// 
// System.Web.UI.HtmlTextWriterStyle
//
// Author:
//        Ben Maurer <bmaurer@novell.com>
//
// (c) 2005 Novell
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System.Web.UI {
#if !NET_2_0
	[Serializable]
#endif
	public enum HtmlTextWriterStyle {
		BackgroundColor,
		BackgroundImage,
		BorderCollapse,
		BorderColor,
		BorderStyle,
		BorderWidth,
		Color,
		FontFamily,
		FontSize,
		FontStyle,
		FontWeight,
		Height,
		TextDecoration,
		Width,
#if NET_2_0
		ListStyleImage,
		ListStyleType,
		Cursor,
		Direction,
		Display,
		Filter,
		FontVariant,
		Left,
		Margin,
		MarginBottom,
		MarginLeft,
		MarginRight,
		MarginTop,
		Overflow,
		OverflowX,
		OverflowY,
		Padding,
		PaddingBottom,
		PaddingLeft,
		PaddingRight,
		PaddingTop,
		Position,
		TextAlign,
		VerticalAlign,
		TextOverflow,
		Top,
		Visibility,
		WhiteSpace,
		ZIndex
#endif
	}

}

==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Web/System.Web.UI/HtmlTextWriterStyle.cs <==
// 
// System.Web.UI.HtmlTextWriterStyle
//
// Author:
//        Ben Maurer <bmaurer@novell.com>
//
// (c) 2005-2010 Novell, Inc (http://novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System.Web.UI
{
	public enum HtmlTextWriterStyle {
		BackgroundColor,
		BackgroundImage,
		BorderCollapse,
		BorderColor,
		BorderStyle,
		BorderWidth,
		Color,
		FontFamily,
		FontSize,
		FontStyle,
		FontWeight,
		Height,
		TextDecoration,
		Width,
		ListStyleImage,
		ListStyleType,
		Cursor,
		Direction,
		Display,
		Filter,
		FontVariant,
		Left,
		Margin,
		MarginBottom,
		MarginLeft,
		MarginRight,
		MarginTop,
		Overflow,
		OverflowX,
		OverflowY,
		Padding,
		PaddingBottom,
		PaddingLeft,
		PaddingRight,
		PaddingTop,
		Position,
		TextAlign,
		VerticalAlign,
		TextOverflow,
		Top,
		Visibility,
		WhiteSpace,
		ZIndex
	}
}
